namespace efl { namespace vpath { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type File::path_get() const
{
   const char * __return_value =  ::efl_vpath_file_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::path_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::efl_vpath_file_path_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type File::result_get() const
{
   const char * __return_value =  ::efl_vpath_file_result_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::result_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::efl_vpath_file_result_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits<bool>::type File::do() const
{
   Eina_Bool __return_value =  ::efl_vpath_file_do(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::wait() const
{
    ::efl_vpath_file_wait(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace efl { namespace vpath { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type File::path_get() const
{
   const char * __return_value =  ::efl_vpath_file_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::path_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::efl_vpath_file_path_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type File::result_get() const
{
   const char * __return_value =  ::efl_vpath_file_result_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::result_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::efl_vpath_file_result_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits<bool>::type File::do() const
{
   Eina_Bool __return_value =  ::efl_vpath_file_do(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type File::wait() const
{
    ::efl_vpath_file_wait(this->_eo_ptr());
}
inline efl::vpath::File::operator ::efl::vpath::File() const { return *static_cast< ::efl::vpath::File const*>(static_cast<void const*>(this)); }
inline efl::vpath::File::operator ::efl::vpath::File&() { return *static_cast< ::efl::vpath::File*>(static_cast<void*>(this)); }
inline efl::vpath::File::operator ::efl::vpath::File const&() const { return *static_cast< ::efl::vpath::File const*>(static_cast<void const*>(this)); }
} } }

